@@ -1,23 +1,20 @@
 #![cfg_attr(feature = "server", feature(proc_macro_hygiene, decl_macro))]
-//#![feature(proc_macro_hygiene, decl_macro)]
-use clap::{crate_name, crate_version};
-use log::*;
 use std::net::TcpListener;
 use std::sync::{Arc, Mutex};
 
+use clap::{crate_name, crate_version};
+use log::*;
+
 mod args;
 mod janitor;
 mod peer_db;
 mod peer_handler;
 mod shared_state;
 
-#[cfg(feature = "server")]
-mod server;
 #[cfg(feature = "metrics")]
 mod metrics;
-
-#[cfg(test)]
-mod tests;
+#[cfg(feature = "server")]
+mod server;
 
 use peer_handler::spawn_handler;
 use shared_state::SharedState;
@@ -59,6 +56,7 @@ fn main() {
   let args = args::get_arguments();
   pretty_env_logger::init_timed();
   info!("Launched {} v{}", crate_name!(), crate_version!());
+  info!("PeerDB type: {}", crate::peer_db::get_peer_db_type());
 
   let shared_state = SharedState::new();
   let shared_state = Arc::new(Mutex::new(shared_state));
